@@ -103,10 +103,6 @@ StubRegistry <- R6::R6Class(
   )
 )
 
-# initialize empty stub registry on package load
-webmockr_stub_registry <- new.env()
-webmockr_stub_registry <- StubRegistry$new()
-
 json_validate <- function(x) {
   res <- tryCatch(jsonlite::validate(x), error = function(e) e)
   if (inherits(res, "error")) return(FALSE)
@@ -117,6 +113,9 @@ json_validate <- function(x) {
 make_body <- function(x) {
   if (is.null(x)) return("")
   if (inherits(x, "mock_file")) x <- x$payload
+  if (inherits(x, "form_file")) x <- unclass(x)
+  clzzes <- vapply(x, function(z) inherits(z, "form_file"), logical(1))
+  if (any(clzzes)) for(i in seq_along(x)) x[[i]] <- unclass(x[[i]])
   if (json_validate(x))
     body <- x
   else
